@@ -64,10 +64,10 @@ class startControl(QThread):
         RIG_PORT = HAMLIB_PORT
         TCP_IP = self.hamlibIPv
         print (TCP_IP, HAMLIB_PORT, self.gqrxIPv, GQRX_PORT)
-        TCP_IP = '''127.0.0.1'''
-        HAMLIB_PORT = '''9537'''
-        self.gqrxIPv = '''127.0.0.1'''
-        GQRX_PORT = '''9536'''
+        TCP_IP = "'127.0.0.1'"
+        HAMLIB_PORT = "'9537'"
+        self.gqrxIPv = "'127.0.0.1'"
+        GQRX_PORT = "'9536'"
         sockGqrx = socket.create_connection((self.gqrxIPv, GQRX_PORT))
         sockHamlib = socket.create_connection((TCP_IP, HAMLIB_PORT))
             #sockHamlib = socket.socket(socket.AF_INET, socket.SOCK_STREAM) 
